@@ -248,6 +248,7 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
 #endif
 
     IpAddress ipAddr = c;
+    ipAddr.SetPort(0);  // ARP will fail if the port is included in the match.
 
 #if defined(_SQUID_LINUX_)
 
@@ -258,6 +259,10 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
     int offset;
 
     SplayNode<acl_arp_data*> **Top = dataptr;
+
+    /* IPv6 builds do not provide the first http_port as an IPv4 socket for ARP */
+    int tmpSocket = socket(AF_INET,SOCK_STREAM,0);
+
     /*
      * The linux kernel 2.2 maintains per interface ARP caches and
      * thus requires an interface name when doing ARP queries.
@@ -279,8 +284,9 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
     ipAddr.GetSockAddr(*sa);
     /* Query ARP table */
 
-    if (ioctl(HttpSockets[0], SIOCGARP, &arpReq) != -1) {
+    if (ioctl(tmpSocket, SIOCGARP, &arpReq) != -1) {
         /* Skip non-ethernet interfaces */
+        close(tmpSocket);
 
         if (arpReq.arp_ha.sa_family != ARPHRD_ETHER) {
             return 0;
@@ -298,7 +304,7 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
         acl_arp_data X;
         memcpy (X.eth, arpReq.arp_ha.sa_data, 6);
         *Top = (*Top)->splay(&X, aclArpCompare);
-        debugs(28, 3, "aclMatchArp: '" << c << "' " << (splayLastResult ? "NOT found" : "found"));
+        debugs(28, 3, "aclMatchArp: '" << ipAddr << "' " << (splayLastResult ? "NOT found" : "found"));
         return (0 == splayLastResult);
     }
 
@@ -307,13 +313,15 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
 
     ifc.ifc_buf = (char *)ifbuffer;
 
-    if (ioctl(HttpSockets[0], SIOCGIFCONF, &ifc) < 0) {
+    if (ioctl(tmpSocket, SIOCGIFCONF, &ifc) < 0) {
         debugs(28, 1, "Attempt to retrieve interface list failed: " << xstrerror());
+        close(tmpSocket);
         return 0;
     }
 
     if (ifc.ifc_len > (int)sizeof(ifbuffer)) {
         debugs(28, 1, "Interface list too long - " << ifc.ifc_len);
+        close(tmpSocket);
         return 0;
     }
 
@@ -332,7 +340,7 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
         if (NULL != strchr(ifr->ifr_name, ':'))
             continue;
 
-        debugs(28, 4, "Looking up ARP address for " << c << " on " << ifr->ifr_name);
+        debugs(28, 4, "Looking up ARP address for " << ipAddr << " on " << ifr->ifr_name);
 
         /* Set up structures for ARP lookup */
 
@@ -346,7 +354,7 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
         arpReq.arp_dev[sizeof(arpReq.arp_dev) - 1] = '\0';
 
         /* Query ARP table */
-        if (-1 == ioctl(HttpSockets[0], SIOCGARP, &arpReq)) {
+        if (-1 == ioctl(tmpSocket, SIOCGARP, &arpReq)) {
             /*
              * Query failed.  Do not log failed lookups or "device
              * not supported"
@@ -384,7 +392,8 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
 
         /* Return if match, otherwise continue to other interfaces */
         if (0 == splayLastResult) {
-            debugs(28, 3, "aclMatchArp: " << c << " found on " << ifr->ifr_name);
+            debugs(28, 3, "aclMatchArp: " << ipAddr << " found on " << ifr->ifr_name);
+            close(tmpSocket);
             return 1;
         }
 
@@ -394,10 +403,15 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
          */
     }
 
+    close(tmpSocket);
+
 #elif defined(_SQUID_SOLARIS_)
 
     SplayNode<acl_arp_data *> **Top = dataptr;
 
+    /* IPv6 builds do not provide the first http_port as an IPv4 socket for ARP */
+    int tmpSocket = socket(AF_INET,SOCK_STREAM,0);
+
     /*
     * Set up structures for ARP lookup with blank interface name
     */
@@ -408,11 +422,12 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
     ipAddr.GetSockAddr(*sa);
 
     /* Query ARP table */
-    if (ioctl(HttpSockets[0], SIOCGARP, &arpReq) != -1) {
+    if (ioctl(tmpSocket, SIOCGARP, &arpReq) != -1) {
         /*
         *  Solaris (at least 2.6/x86) does not use arp_ha.sa_family -
         * it returns 00:00:00:00:00:00 for non-ethernet media
         */
+        close(tmpSocket);
 
         if (arpReq.arp_ha.sa_data[0] == 0 &&
                 arpReq.arp_ha.sa_data[1] == 0 &&
@@ -432,12 +447,14 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
         /* Do lookup */
         *Top = (*Top)->splay((acl_arp_data *)&arpReq.arp_ha.sa_data, aclArpCompare);
 
-        debugs(28, 3, "aclMatchArp: '" << c << "' " << (splayLastResult ? "NOT found" : "found"));
+        debugs(28, 3, "aclMatchArp: '" << ipAddr << "' " << (splayLastResult ? "NOT found" : "found"));
 
         return (0 == splayLastResult);
     }
 
-#elif defined(_SQUID_FREEBSD_) || defined(_SQUID_NETBSD_) || defined(_SQUID_OPENBSD_) || defined(_SQUID_DRAGONFLY_)
+    close(tmpSocket);
+
+#elif defined(_SQUID_FREEBSD_) || defined(_SQUID_NETBSD_) || defined(_SQUID_OPENBSD_) || defined(_SQUID_DRAGONFLY_) || defined(_SQUID_KFREEBSD_)
 
     SplayNode<acl_arp_data *> **Top = dataptr;
 
@@ -533,7 +550,7 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
     /* Do lookup */
     *Top = (*Top)->splay((acl_arp_data *)&arpReq.arp_ha.sa_data, aclArpCompare);
 
-    debugs(28, 3, "aclMatchArp: '" << c << "' " << (splayLastResult ? "NOT found" : "found"));
+    debugs(28, 3, "aclMatchArp: '" << ipAddr << "' " << (splayLastResult ? "NOT found" : "found"));
 
     return (0 == splayLastResult);
 
@@ -598,7 +615,7 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
     /* Do lookup */
     *Top = (*Top)->splay((acl_arp_data *)&arpReq.arp_ha.sa_data, aclArpCompare);
 
-    debugs(28, 3, "aclMatchArp: '" << c << "' " << (splayLastResult ? "NOT found" : "found"));
+    debugs(28, 3, "aclMatchArp: '" << ipAddr << "' " << (splayLastResult ? "NOT found" : "found"));
 
     return (0 == splayLastResult);
 
@@ -610,7 +627,7 @@ aclMatchArp(SplayNode<acl_arp_data *> **dataptr, IpAddress &c)
     /*
      * Address was not found on any interface
      */
-    debugs(28, 3, "aclMatchArp: " << c << " NOT found");
+    debugs(28, 3, "aclMatchArp: " << ipAddr << " NOT found");
 
     return 0;
 }
