@@ -1,6 +1,6 @@
 
 /*
- * $Id: internal.cc,v 1.48 2007/12/14 23:11:47 amosjeffries Exp $
+ * $Id$
  *
  * DEBUG: section 76    Internal Squid Object handling
  * AUTHOR: Duane, Alex, Henrik
@@ -51,7 +51,7 @@ void
 internalStart(HttpRequest * request, StoreEntry * entry)
 {
     ErrorState *err;
-    const char *upath = request->urlpath.buf();
+    const char *upath = request->urlpath.termedBuf();
     debugs(76, 3, "internalStart: " << request->client_addr << " requesting '" << upath << "'");
 
     if (0 == strcmp(upath, "/squid-internal-dynamic/netdb")) {
@@ -64,15 +64,8 @@ internalStart(HttpRequest * request, StoreEntry * entry)
         const char *msgbuf = "This cache does not support Cache Digests.\n";
 #endif
 
-        HttpVersion version(1, 0);
         HttpReply *reply = new HttpReply;
-        reply->setHeaders(version,
-                          HTTP_NOT_FOUND,
-                          "Not Found",
-                          "text/plain",
-                          strlen(msgbuf),
-                          squid_curtime,
-                          -2);
+        reply->setHeaders(HTTP_NOT_FOUND, "Not Found", "text/plain", strlen(msgbuf), squid_curtime, -2);
         entry->replaceHttpReply(reply);
         entry->append(msgbuf, strlen(msgbuf));
         entry->complete();
@@ -121,7 +114,12 @@ internalRemoteUri(const char *host, u_short port, const char *dir, const char *n
      * domains
      */
 
+#if USE_IPV6
+    /* For IPV6 addresses also check for a colon */
+    if (Config.appendDomain && !strchr(lc_host, '.') && !strchr(lc_host, ':'))
+#else
     if (Config.appendDomain && !strchr(lc_host, '.'))
+#endif
         strncat(lc_host, Config.appendDomain, SQUIDHOSTNAMELEN -
                 strlen(lc_host) - 1);
 
@@ -161,7 +159,12 @@ internalHostname(void)
     LOCAL_ARRAY(char, host, SQUIDHOSTNAMELEN + 1);
     xstrncpy(host, getMyHostname(), SQUIDHOSTNAMELEN);
 
+#if USE_IPV6
+    /* For IPV6 addresses also check for a colon */
+    if (Config.appendDomain && !strchr(host, '.') && !strchr(host, ':'))
+#else
     if (Config.appendDomain && !strchr(host, '.'))
+#endif
         strncat(host, Config.appendDomain, SQUIDHOSTNAMELEN -
                 strlen(host) - 1);
 
