@@ -273,15 +273,15 @@ refreshCheck(const StoreEntry * entry, HttpRequest * request, time_t delta)
 
     if (EBIT_TEST(entry->flags, ENTRY_REVALIDATE) && staleness > -1
 #if HTTP_VIOLATIONS
-        && !R->flags.ignore_must_revalidate
+            && !R->flags.ignore_must_revalidate
 #endif
-    ) {
+       ) {
         debugs(22, 3, "refreshCheck: YES: Must revalidate stale response");
         return STALE_MUST_REVALIDATE;
     }
 
     /* request-specific checks */
-    if (request) {
+    if (request && !request->flags.ignore_cc) {
         HttpHdrCc *cc = request->cache_control;
 
         if (request->flags.ims && (R->flags.refresh_ims || Config.onoff.refresh_all_ims)) {
